@@ -1,10 +1,10 @@
-## ---- include = FALSE----------------------------------------------------
+## ---- include = FALSE---------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----setup, message=FALSE------------------------------------------------
+## ----setup, message=FALSE-----------------------------------------------------
 library(dplyr)
 library(eSDM)
 library(lwgeom)
@@ -12,7 +12,7 @@ library(sf)
 
 source(system.file("eSDM_vignette_helper.R", package = "eSDM"), local = TRUE, echo = FALSE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Import, process, and plot Model_B predictions
 # model.b <- read.csv("Predictions_Beckeretal2016.csv")
 model.b.sf <- readRDS(system.file("extdata/Predictions_Beckeretal2016.rds", package = "eSDM")) %>% 
@@ -28,10 +28,13 @@ map.world <- eSDM::gshhg.l.L16
 # Other option for making base map
 # map.world <- st_geometry(st_as_sf(maps::map('world', plot = FALSE, fill = TRUE)))
 
-## ---- fig.width=7--------------------------------------------------------
-plot_sf_3panel(model.b.sf, "pred_bm", main.txt = "Model_B - ", map.base = map.world)
+## ---- fig.width=7, fig.height=3-----------------------------------------------
+plot_sf_3panel(
+  model.b.sf, "pred_bm", main.txt = "Model_B - ", map.base = map.world, 
+  x.axis.at = c(-130, -125, -120)
+)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Import, process, and plot Model_H predictions
 # model.h <- read.csv("Predictions_Hazenetal2017.csv")
 model.h.sf <- readRDS(system.file("extdata/Predictions_Hazenetal2017.rds", package = "eSDM")) %>% 
@@ -40,10 +43,13 @@ model.h.sf <- readRDS(system.file("extdata/Predictions_Hazenetal2017.rds", packa
 
 model.h.sf
 
-## ---- fig.width=7--------------------------------------------------------
-plot_sf_3panel(model.h.sf, "pred_bm", main.txt = "Model_H - ", map.base = map.world)
+## ---- fig.width=7, fig.height=3-----------------------------------------------
+plot_sf_3panel(
+  model.h.sf, "pred_bm", main.txt = "Model_H - ", map.base = map.world, 
+  x.axis.at = c(-135, -130, -125, -120)
+)
 
-## ---- fig.width=7--------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Import, process, and plot Model_R predictions
 # model.r <- st_read("Shapefiles/Predictions_Redfernetal2017.shp")
 model.r.sf <- readRDS(system.file("extdata/Predictions_Redfernetal2017.rds", package = "eSDM")) %>% 
@@ -52,16 +58,19 @@ model.r.sf <- readRDS(system.file("extdata/Predictions_Redfernetal2017.rds", pac
 
 model.r.sf
 
-## ---- fig.width=7--------------------------------------------------------
-plot_sf_3panel(model.r.sf, "pred_bm", main.txt = "Model_R - ", map.base = map.world)
+## ---- fig.width=7, fig.height=3-----------------------------------------------
+plot_sf_3panel(
+  model.r.sf, "pred_bm", main.txt = "Model_R - ", map.base = map.world, 
+  x.axis.at = c(-130, -125, -120)
+)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  # Example code for converting raster to sf object; code not run
 #  logo <- raster::raster(system.file("external/rlogo.grd", package="raster"))
 #  logo.sf <- as(logo, "SpatialPolygonsDataFrame") %>%
 #    sf::st_as_sf()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Study area polygon
 poly.study <- st_read(system.file("extdata/Shapefiles/Study_Area_CCE.shp", package = "eSDM")) %>%
   st_geometry() %>% 
@@ -80,13 +89,13 @@ base.geom <- model.r.sf %>%
   st_intersection(poly.study) %>%
   st_cast("MULTIPOLYGON")
 
-## ---- fig.width=5, fig.height=7------------------------------------------
+## ---- fig.width=5, fig.height=7-----------------------------------------------
 # Visualize the base geometry
 plot(st_transform(base.geom, 4326), col = NA, border = "black", axes = TRUE)
 plot(map.world, add = TRUE, col = "tan", border = NA)
 graphics::box()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Convert SE values to variance
 model.b.sf <- model.b.sf %>% 
   mutate(variance = se^2) %>% 
@@ -98,7 +107,7 @@ model.r.sf <- model.r.sf %>%
   mutate(variance = se^2) %>% 
   dplyr::select(pred_bm, se, variance)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Perform overlay, and convert overlaid uncertainty values to SEs
 over1.sf <- eSDM::overlay_sdm(base.geom, st_transform(model.b.sf, st_crs(base.geom)), c("pred_bm", "variance"), 50) %>% 
   mutate(se = sqrt(variance))
@@ -116,13 +125,13 @@ all.equal(over3.sf, over3.sfb)
 rm(over3.sfb)
 
 
-## ---- fig.width=7, eval=FALSE--------------------------------------------
+## ---- fig.width=7, fig.height=3, eval=FALSE-----------------------------------
 #  # Plot overlaid predictions; code not run
 #  plot_sf_3panel(over1.sf, "pred_bm", main.txt = "Overlaid Model_B - ", map.base = map.world)
 #  plot_sf_3panel(over2.sf, "pred_bm", main.txt = "Overlaid Model_H - ", map.base = map.world)
 #  plot_sf_3panel(over3.sf, "pred_bm", main.txt = "Overlaid Model_R - ", map.base = map.world)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Import and process validation data
 # valid.data <- read.csv("eSDM_Validation_data_all.csv", stringsAsFactors = FALSE)
 valid.data <- readRDS(system.file("extdata/eSDM_Validation_data_all.rds", package = "eSDM"))%>% 
@@ -143,7 +152,7 @@ valid.data %>%
             abs = sum(pres_abs == 0)) %>% 
   knitr::kable(caption = "Validation data summary")
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  # Calculate evaluation metrics with different validation data sets; code not run
 #  names.1 <- c(
 #    "Model_B_orig", "Model_H_orig", "Model_R_orig",
@@ -183,14 +192,14 @@ valid.data %>%
 #    mutate(Preds = names.1) %>%
 #    dplyr::select(Preds, AUC = X1, TSS = X2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 read.csv(system.file("extdata/Table3.csv", package = "eSDM")) %>%
   filter(grepl("Model_", Predictions)) %>% 
   dplyr::select(Predictions, AUC, TSS, `AUC-LT` = AUC.LT, `TSS-LT` = TSS.LT, 
-         `AUC-HR` = AUC.HR, `TSS-HR` = TSS.HR) %>% 
+                `AUC-HR` = AUC.HR, `TSS-HR` = TSS.HR) %>% 
   knitr::kable(caption = "Evaluation metrics", digits = 3, align = "lcccccc")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Rescale predictions
 over.sf <- bind_cols(
   over1.sf %>% st_set_geometry(NULL) %>% dplyr::select(pred_bm1 = pred_bm, var1 = variance), 
@@ -211,7 +220,7 @@ eSDM::model_abundance(over.sf.rescaled, "pred_bm3")
 
 summary(over.sf.rescaled)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Calculate ensemble weights
 e.weights <- list(
   eSDM::evaluation_metrics(over1.sf, 1, valid.data, "pres_abs"), 
@@ -235,7 +244,7 @@ e.weights.auc
 e.weights.tss
 head(e.weights.var)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ### Create ensembles
 
 # Unweighted; calculate CV because it is used in Fig. 4 plot
@@ -274,7 +283,7 @@ ens.sf.wvar <- eSDM::ensemble_create(
   dplyr::select(Pred_ens, SE) %>% 
   st_set_agr("constant")
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  # Create an ensemble and calculate within-model uncertainty; code not run
 #  ens.sf.unw.wmv <- eSDM::ensemble_create(
 #    over.sf.rescaled, c("pred_bm1", "pred_bm2", "pred_bm3"),  w = e.weights.unw,
@@ -283,7 +292,7 @@ ens.sf.wvar <- eSDM::ensemble_create(
 #    mutate(SE = sqrt(Var_ens)) %>%
 #    dplyr::select(Pred_ens , SE)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  # Calculate evaluation metrics for ensembles; code not run
 #  names.2 <- c(
 #    "Ensemble – unweighted", "Ensemble – AUC-based weights",
@@ -317,20 +326,20 @@ ens.sf.wvar <- eSDM::ensemble_create(
 #    mutate(Preds = names.2) %>%
 #    dplyr::select(Preds, AUC = X1, TSS = X2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 read.csv(system.file("extdata/Table3.csv", package = "eSDM")) %>%
   dplyr::select(Predictions, AUC, TSS, `AUC-LT` = AUC.LT, `TSS-LT` = TSS.LT, 
-         `AUC-HR` = AUC.HR, `TSS-HR` = TSS.HR) %>% 
+                `AUC-HR` = AUC.HR, `TSS-HR` = TSS.HR) %>% 
   knitr::kable(caption = "Evaluation metrics", digits = 3, align = "lcccccc")
 
-## ---- fig.width=7--------------------------------------------------------
+## ---- fig.width=7, fig.height=3-----------------------------------------------
 # Simple code to visualize ensemble created with weights based on TSS values
 plot_sf_3panel(
   rename(ens.sf.wtss, se = SE), "Pred_ens", main.txt = "Ensemble-TSS - ", 
-  map.base = map.world
+  map.base = map.world, x.axis.at = c(-130, -125, -120)
 )
 
-## ---- fig.width=7, fig.height=4, eval=FALSE------------------------------
+## ---- fig.width=7, fig.height=4, eval=FALSE-----------------------------------
 #  ### Figure 4; code not run
 #  library(tmap)
 #  
@@ -377,7 +386,7 @@ plot_sf_3panel(
 #    list(tmap.obj1, tmap.obj2, tmap.obj3), ncol = 3, asp = NULL, outer.margins = 0.05
 #  )
 
-## ---- fig.height=9, fig.width=5.7, eval=FALSE----------------------------
+## ---- fig.height=9, fig.width=5.7, eval=FALSE---------------------------------
 #  ### Figure 5; code not run
 #  
 #  # Values passed to tmap_sdm - size of text labels and legend width
